# geobay


[![image](https://img.shields.io/pypi/v/geoproject510.svg)](https://pypi.python.org/pypi/geobay)
[![image](https://img.shields.io/conda/vn/conda-forge/geobay.svg)](https://anaconda.org/conda-forge/geobay)


**python package for geog 510**


-   Free software: MIT License
-   Documentation: https://Caseyshea96.github.io/geobay


## Features

-   TODO
